EXPORTS
	??0CPort@@QAE@XZ @ 1 NONAME ; public: __thiscall CPort::CPort(void)
	??0CSerial@@QAE@XZ @ 2 NONAME ; public: __thiscall CSerial::CSerial(void)
	??0RCommServ@@QAE@XZ @ 3 NONAME ; public: __thiscall RCommServ::RCommServ(void)
	??1CPort@@UAE@XZ @ 4 NONAME ; public: virtual __thiscall CPort::~CPort(void)
	??1CSerial@@UAE@XZ @ 5 NONAME ; public: virtual __thiscall CSerial::~CSerial(void)
	?Break@RComm@@QAEXAAVTRequestStatus@@VTTimeIntervalMicroSeconds32@@@Z @ 6 NONAME ; public: void __thiscall RComm::Break(class TRequestStatus &,class TTimeIntervalMicroSeconds32)
	?BreakCompleted@CPort@@QAEXH@Z @ 7 NONAME ; public: void __thiscall CPort::BreakCompleted(int)
	?Cancel@RComm@@QAEHXZ @ 8 NONAME ; public: int __thiscall RComm::Cancel(void)
	?Caps@RComm@@QBEHAAVTDes8@@@Z @ 9 NONAME ; public: int __thiscall RComm::Caps(class TDes8 &)const 
	?Close@CPort@@UAEXXZ @ 10 NONAME ; public: virtual void __thiscall CPort::Close(void)
	?Close@RComm@@QAEXXZ @ 11 NONAME ; public: void __thiscall RComm::Close(void)
	?Config@RComm@@QBEHAAVTDes8@@@Z @ 12 NONAME ; public: int __thiscall RComm::Config(class TDes8 &)const 
	?Connect@RCommServ@@QAEHXZ @ 13 NONAME ; public: int __thiscall RCommServ::Connect(void)
	?GetPortInfo@RCommServ@@QAEHABVTDesC16@@AAVTSerialInfo@@@Z @ 14 NONAME ; public: int __thiscall RCommServ::GetPortInfo(class TDesC16 const &,class TSerialInfo &)
	?GetPortInfo@RCommServ@@QAEHHAAVTDes16@@AAVTSerialInfo@@@Z @ 15 NONAME ; public: int __thiscall RCommServ::GetPortInfo(int,class TDes16 &,class TSerialInfo &)
	?IPCRead@CPort@@QBEHPBXAAVTDes8@@H@Z @ 16 NONAME ; public: int __thiscall CPort::IPCRead(void const *,class TDes8 &,int)const 
	?IPCWrite@CPort@@QBEHPBXABVTDesC8@@H@Z @ 17 NONAME ; public: int __thiscall CPort::IPCWrite(void const *,class TDesC8 const &,int)const 
	?LoadCommModule@RCommServ@@QAEHABVTDesC16@@@Z @ 18 NONAME ; public: int __thiscall RCommServ::LoadCommModule(class TDesC16 const &)
	?Mode@RComm@@QBEHAAV?$TPckgBuf@UTCommServerConfigV01@@@@@Z @ 19 NONAME ; public: int __thiscall RComm::Mode(class TPckgBuf<struct TCommServerConfigV01> &)const 
	?NumPorts@RCommServ@@QAEHAAH@Z @ 20 NONAME ; public: int __thiscall RCommServ::NumPorts(int &)
	?Open@RComm@@QAEHAAVRCommServ@@ABVTDesC16@@W4TCommAccess@@@Z @ 21 NONAME ; public: int __thiscall RComm::Open(class RCommServ &,class TDesC16 const &,enum TCommAccess)
	?QueryReceiveBuffer@RComm@@QBEHXZ @ 22 NONAME ; public: int __thiscall RComm::QueryReceiveBuffer(void)const 
	?QueryVersionSupported@CSerial@@UBEHABVTVersion@@@Z @ 23 NONAME ; public: virtual int __thiscall CSerial::QueryVersionSupported(class TVersion const &)const 
	?Queue@CommTimer@@SAXVTTimeIntervalMicroSeconds32@@AAVTDeltaTimerEntry@@@Z @ 24 NONAME ; public: static void __cdecl CommTimer::Queue(class TTimeIntervalMicroSeconds32,class TDeltaTimerEntry &)
	?Read@RComm@@QAEXAAVTRequestStatus@@AAVTDes8@@@Z @ 25 NONAME ; public: void __thiscall RComm::Read(class TRequestStatus &,class TDes8 &)
	?Read@RComm@@QAEXAAVTRequestStatus@@AAVTDes8@@H@Z @ 26 NONAME ; public: void __thiscall RComm::Read(class TRequestStatus &,class TDes8 &,int)
	?Read@RComm@@QAEXAAVTRequestStatus@@VTTimeIntervalMicroSeconds32@@AAVTDes8@@@Z @ 27 NONAME ; public: void __thiscall RComm::Read(class TRequestStatus &,class TTimeIntervalMicroSeconds32,class TDes8 &)
	?Read@RComm@@QAEXAAVTRequestStatus@@VTTimeIntervalMicroSeconds32@@AAVTDes8@@H@Z @ 28 NONAME ; public: void __thiscall RComm::Read(class TRequestStatus &,class TTimeIntervalMicroSeconds32,class TDes8 &,int)
	?ReadCancel@RComm@@QAEHXZ @ 29 NONAME ; public: int __thiscall RComm::ReadCancel(void)
	?ReadCompleted@CPort@@QAEXH@Z @ 30 NONAME ; public: void __thiscall CPort::ReadCompleted(int)
	?ReadOneOrMore@RComm@@QAEXAAVTRequestStatus@@AAVTDes8@@@Z @ 31 NONAME ; public: void __thiscall RComm::ReadOneOrMore(class TRequestStatus &,class TDes8 &)
	?ReceiveBufferLength@RComm@@QBEHXZ @ 32 NONAME ; public: int __thiscall RComm::ReceiveBufferLength(void)const 
	?Remove@CommTimer@@SAXAAVTDeltaTimerEntry@@@Z @ 33 NONAME ; public: static void __cdecl CommTimer::Remove(class TDeltaTimerEntry &)
	?ResetBuffers@RComm@@QAEHI@Z @ 34 NONAME ; public: int __thiscall RComm::ResetBuffers(unsigned int)
	?RunCommServer@@YAHPAUTCFModuleInfo@CommsFW@@@Z @ 35 NONAME ; int __cdecl RunCommServer(CommsFW::TCFModuleInfo *)
	?SetConfig@RComm@@QAEHABVTDesC8@@@Z @ 36 NONAME ; public: int __thiscall RComm::SetConfig(class TDesC8 const &)
	?SetMode@RComm@@QAEHABV?$TPckgBuf@UTCommServerConfigV01@@@@@Z @ 37 NONAME ; public: int __thiscall RComm::SetMode(class TPckgBuf<struct TCommServerConfigV01> const &)
	?SetReceiveBufferLength@RComm@@QAEHH@Z @ 38 NONAME ; public: int __thiscall RComm::SetReceiveBufferLength(int)
	?SetSignalsToMark@RComm@@QAEHI@Z @ 39 NONAME ; public: int __thiscall RComm::SetSignalsToMark(unsigned int)
	?SetSignalsToSpace@RComm@@QAEHI@Z @ 40 NONAME ; public: int __thiscall RComm::SetSignalsToSpace(unsigned int)
	?Signals@RComm@@QBEII@Z @ 41 NONAME ; public: unsigned int __thiscall RComm::Signals(unsigned int)const 
	?StartC32@@YAHXZ @ 42 NONAME ; int __cdecl StartC32(void)
	?UnloadCommModule@RCommServ@@QAEHABVTDesC16@@@Z @ 43 NONAME ; public: int __thiscall RCommServ::UnloadCommModule(class TDesC16 const &)
	?Version@RCommServ@@QBE?AVTVersion@@XZ @ 44 NONAME ; public: class TVersion  __thiscall RCommServ::Version(void)const 
	?Write@RComm@@QAEXAAVTRequestStatus@@ABVTDesC8@@@Z @ 45 NONAME ; public: void __thiscall RComm::Write(class TRequestStatus &,class TDesC8 const &)
	?Write@RComm@@QAEXAAVTRequestStatus@@ABVTDesC8@@H@Z @ 46 NONAME ; public: void __thiscall RComm::Write(class TRequestStatus &,class TDesC8 const &,int)
	?Write@RComm@@QAEXAAVTRequestStatus@@VTTimeIntervalMicroSeconds32@@ABVTDesC8@@@Z @ 47 NONAME ; public: void __thiscall RComm::Write(class TRequestStatus &,class TTimeIntervalMicroSeconds32,class TDesC8 const &)
	?Write@RComm@@QAEXAAVTRequestStatus@@VTTimeIntervalMicroSeconds32@@ABVTDesC8@@H@Z @ 48 NONAME ; public: void __thiscall RComm::Write(class TRequestStatus &,class TTimeIntervalMicroSeconds32,class TDesC8 const &,int)
	?WriteCancel@RComm@@QAEHXZ @ 49 NONAME ; public: int __thiscall RComm::WriteCancel(void)
	?WriteCompleted@CPort@@QAEXH@Z @ 50 NONAME ; public: void __thiscall CPort::WriteCompleted(int)
	?BreakCancel@RComm@@QAEHXZ @ 51 NONAME ; public: int __thiscall RComm::BreakCancel(void)
	?__DbgCheckHeap@RCommServ@@QAEHH@Z @ 52 NONAME ; public: int __thiscall RCommServ::__DbgCheckHeap(int)
	?__DbgFailNext@RCommServ@@QAEHH@Z @ 53 NONAME ; public: int __thiscall RCommServ::__DbgFailNext(int)
	?__DbgMarkEnd@RCommServ@@QAEHH@Z @ 54 NONAME ; public: int __thiscall RCommServ::__DbgMarkEnd(int)
	?__DbgMarkHeap@RCommServ@@QAEHXZ @ 55 NONAME ; public: int __thiscall RCommServ::__DbgMarkHeap(void)
	?__DbgSetTraceMask@RCommServ@@QAEHW4TC32Trace@@@Z @ 56 NONAME ; public: int __thiscall RCommServ::__DbgSetTraceMask(enum TC32Trace)
	?BreakNotifyCompleted@CPort@@QAEXH@Z @ 57 NONAME ; public: void __thiscall CPort::BreakNotifyCompleted(int)
	?ConfigChangeCompleted@CPort@@QAEXABVTDesC8@@H@Z @ 58 NONAME ; public: void __thiscall CPort::ConfigChangeCompleted(class TDesC8 const &,int)
	?FlowControlChangeCompleted@CPort@@QAEXABW4TFlowControl@@H@Z @ 59 NONAME ; public: void __thiscall CPort::FlowControlChangeCompleted(enum TFlowControl const &,int)
	?GetFlowControlStatus@RComm@@QBEHAAW4TFlowControl@@@Z @ 60 NONAME ; public: int __thiscall RComm::GetFlowControlStatus(enum TFlowControl &)const 
	?GetRole@RComm@@QBEHAAW4TCommRole@@@Z @ 61 NONAME ; public: int __thiscall RComm::GetRole(enum TCommRole &)const 
	?NotifyBreak@RComm@@QBEXAAVTRequestStatus@@@Z @ 62 NONAME ; public: void __thiscall RComm::NotifyBreak(class TRequestStatus &)const 
	?NotifyBreakCancel@RComm@@QBEHXZ @ 63 NONAME ; public: int __thiscall RComm::NotifyBreakCancel(void)const 
	?NotifyConfigChange@RComm@@QBEXAAVTRequestStatus@@AAVTDes8@@@Z @ 64 NONAME ; public: void __thiscall RComm::NotifyConfigChange(class TRequestStatus &,class TDes8 &)const 
	?NotifyConfigChangeCancel@RComm@@QBEHXZ @ 65 NONAME ; public: int __thiscall RComm::NotifyConfigChangeCancel(void)const 
	?NotifyFlowControlChange@RComm@@QAEXAAVTRequestStatus@@AAW4TFlowControl@@@Z @ 66 NONAME ; public: void __thiscall RComm::NotifyFlowControlChange(class TRequestStatus &,enum TFlowControl &)
	?NotifyFlowControlChangeCancel@RComm@@QBEHXZ @ 67 NONAME ; public: int __thiscall RComm::NotifyFlowControlChangeCancel(void)const 
	?NotifySignalChange@RComm@@QAEXAAVTRequestStatus@@AAII@Z @ 68 NONAME ; public: void __thiscall RComm::NotifySignalChange(class TRequestStatus &,unsigned int &,unsigned int)
	?NotifySignalChangeCancel@RComm@@QBEHXZ @ 69 NONAME ; public: int __thiscall RComm::NotifySignalChangeCancel(void)const 
	?Open@RComm@@QAEHAAVRCommServ@@ABVTDesC16@@W4TCommAccess@@W4TCommRole@@@Z @ 70 NONAME ; public: int __thiscall RComm::Open(class RCommServ &,class TDesC16 const &,enum TCommAccess,enum TCommRole)
	?SignalChangeCompleted@CPort@@QAEXABIH@Z @ 71 NONAME ; public: void __thiscall CPort::SignalChangeCompleted(unsigned int const &,int)
	?NotifyDataAvailable@RComm@@QBEXAAVTRequestStatus@@@Z @ 72 NONAME ; public: void __thiscall RComm::NotifyDataAvailable(class TRequestStatus &)const 
	?NotifyDataAvailableCancel@RComm@@QBEHXZ @ 73 NONAME ; public: int __thiscall RComm::NotifyDataAvailableCancel(void)const 
	?NotifyOutputEmpty@RComm@@QBEXAAVTRequestStatus@@@Z @ 74 NONAME ; public: void __thiscall RComm::NotifyOutputEmpty(class TRequestStatus &)const 
	?NotifyOutputEmptyCancel@RComm@@QBEHXZ @ 75 NONAME ; public: int __thiscall RComm::NotifyOutputEmptyCancel(void)const 
	?NotifyDataAvailableCompleted@CPort@@QAEXH@Z @ 76 NONAME ; public: void __thiscall CPort::NotifyDataAvailableCompleted(int)
	?NotifyOutputEmptyCompleted@CPort@@QAEXH@Z @ 77 NONAME ; public: void __thiscall CPort::NotifyOutputEmptyCompleted(int)
	??0RComm@@QAE@XZ @ 78 NONAME ; public: __thiscall RComm::RComm(void)
	?CreateThreadInCommProc@RCommServ@@SAHABVTDesC16@@0P6AHPAX@ZHHH@Z @ 79 NONAME ; public: static int __cdecl RCommServ::CreateThreadInCommProc(class TDesC16 const &,class TDesC16 const &,int (__cdecl*)(void *),int,int,int)
	?DebugState@RComm@@QAEHAAUTCommDebugInfo@@@Z @ 80 NONAME ; public: int __thiscall RComm::DebugState(struct TCommDebugInfo &)
	?OpenWhenAvailable@RComm@@QAEXAAVTRequestStatus@@AAVRCommServ@@ABVTDesC16@@@Z @ 81 NONAME ; public: void __thiscall RComm::OpenWhenAvailable(class TRequestStatus &,class RCommServ &,class TDesC16 const &)
	?SetAccessMode@RComm@@QAEHW4TCommAccess@@@Z @ 82 NONAME ; public: int __thiscall RComm::SetAccessMode(enum TCommAccess)
	?OpenWhenAvailableCancel@RComm@@QAEXXZ @ 83 NONAME ; public: void __thiscall RComm::OpenWhenAvailableCancel(void)
	?CPort_Reserved1@CPort@@EAEXXZ @ 84 NONAME ; private: virtual void __thiscall CPort::CPort_Reserved1(void)
	?CSerial_Reserved1@CSerial@@EAEXXZ @ 85 NONAME ; private: virtual void __thiscall CSerial::CSerial_Reserved1(void)
	?OpenWhenAvailable@RComm@@QAEXAAVTRequestStatus@@AAVRCommServ@@ABVTDesC16@@W4TCommRole@@@Z @ 86 NONAME ; public: void __thiscall RComm::OpenWhenAvailable(class TRequestStatus &,class RCommServ &,class TDesC16 const &,enum TCommRole)
	?CommServerThreadEntryPoint@@YAHPAX@Z @ 87 NONAME ; int __cdecl CommServerThreadEntryPoint(void *)
	?PortPlatSecCapability@CSerial@@UBE?AVTSecurityPolicy@@I@Z @ 88 NONAME ; class TSecurityPolicy CSerial::PortPlatSecCapability(unsigned int) const

